/************************************************************************************************************************
*
*	Policing Ethnicity:
*	Lab-in-the-Field Evidence on Discrimination, Cooperation, and Ethnic Balancing in the Liberian National Police
*	
*	Robert A. Blair, Sabrina M. Karim, Michael J. Gilligan, and Kyle Beardsley
*
*	Quarterly Journal of Political Science
*
*	Replication Files
*
************************************************************************************************************************/



				clear
				set more off, permanently

				
				
	* Change directory
				
				gl ETHNICITY "[YOUR DIRECTORY]"
				
				cd "$ETHNICITY"
				
				
	
	* Load data
	
				use "data.dta", clear
				
				
				
				
	* Define globals
		
			/* Dependent variables */

				* Paritcipant level
				
					gl I_COOPERATION arguemean i_altruism_same_kept no_feelcomfortable no_listen no_groupthink no_happydiscussion no_happydecisison no_sameteamlnp
	
					gl I_COOPERATION_hetero arguemean i_altruism_same_kept no_feelcomfortable no_listen no_groupthink no_happydiscussion no_sameteamlnp					

					gl I_DISCRIMINATION mandingo_mostguilty mandingo_mostliar mandingo_leastimportant mostcrime_mand_mix
		
					gl I_DISCRIMINATION_hetero mandingo_mostguilty mandingo_mostliar mandingo_leastimportant

					gl I_DISCRIMINATION_alt mandingo_mostguilty mandingo_mostliar mandingo_leastimportant
					
				* Team level
				
					gl G_COOPERATION arguegroup avg_altruism_same_kept g_no_feelcomfortable g_no_listen g_no_groupthink g_no_happydiscussion g_no_happydecisison g_no_sameteamlnp talknhgroup decision_nonconsen

					gl G_COOPERATION_alt arguegroup avg_altruism_same_kept g_no_feelcomfortable g_no_listen g_no_groupthink g_no_happydiscussion g_no_happydecisison g_no_sameteamlnp talknhgroup decision_nonconsen meanmost_guilty_match meanmost_liar_match meanmost_important_match
					
					gl G_COOPERATION_hetero arguegroup avg_altruism_same_kept g_no_feelcomfortable g_no_listen g_no_groupthink g_no_happydiscussion g_no_sameteamlnp talknhgroup decision_nonconsen 

					gl G_DISCRIMINATION g_mandingo_mostguilty g_mandingo_mostliar g_mandingo_leastimportant g_mostcrime_mand_mix
	
					gl G_DISCRIMINATION_hetero g_mandingo_mostguilty g_mandingo_mostliar g_mandingo_leastimportant

					gl G_DISCRIMINATION_alt g_mandingo_mostguilty g_mandingo_mostliar g_mandingo_leastimportant		
	
			/* Controls */

				* Participant level
			
					gl I_CONTROLS fem over40 university income psu_eru corporal_plus lnpserveyears cogscore friends 
				
				* Team level
				
					gl G_CONTROLS meanfem meanover40 meanuniversity meanincome meanpsu_eru meancorporal_plus meanlnpserveyears meancogscore meanfriends 
				
				* Fixed effects
				
					gl FE lofa nimba	
				






*********
* PAPER *
*********	



	* Replicate table 1
																																	
					* 1 treatment dummy
						
						preserve
						
						qui avg_effect $G_COOPERATION if ind_code==1, ///
							effectvar(treatment_alt) controltest(treatment_alt==0) x(treatment_alt $G_CONTROLS $FE)
								outreg2 treatment_alt using "table1.xls", excel dec(2) aster(se) br replace
						foreach x in $G_COOPERATION {
							qui drop if `x'==.
							}		
						foreach x in $G_COOPERATION {
							qui reg `x' treatment_alt $G_CONTROLS $FE if ind_code==1
								estimates store `x'
								}
							qui suest $G_COOPERATION
							outreg2 using "table1.xls", excel dec(2) keep(treatment_alt) aster(se) br nocons append
						
						restore
					
					* 2 treatment dummies
					
						preserve
						
						qui avg_effect $G_COOPERATION if ind_code==1, ///
							effectvar(treatment_1 treatment_2) controltest(control==1) x(treatment_1 treatment_2 $G_CONTROLS $FE)
								outreg2 treatment_1 treatment_2 using "table1.xls", excel dec(2) aster(se) br append
						foreach x in $G_COOPERATION {
							qui drop if `x'==.
							}		
						foreach x in $G_COOPERATION {
							qui reg `x' treatment_1 treatment_2 $G_CONTROLS $FE if ind_code==1
								estimates store `x'
								}
							qui suest $G_COOPERATION
							outreg2 using "table1.xls", excel dec(2) keep(treatment_1 treatment_2) aster(se) br nocons append
						
						restore
						
						
						
						
	* Replicate table 2
																																	
					* 1 treatment dummy
						
						preserve
						
						qui avg_effect $I_COOPERATION if mandingo==0, ///
							effectvar(treatment_alt) controltest(treatment_alt==0) x(treatment_alt $I_CONTROLS $FE) cluster(group_code_master)
								outreg2 treatment_alt using "table2.xls", excel dec(2) aster(se) br replace
						foreach x in $I_COOPERATION {
							qui drop if `x'==.
							}		
						foreach x in $I_COOPERATION {
							qui reg `x' treatment_alt $I_CONTROLS $FE if mandingo==0
								estimates store `x'
								}
							qui suest $I_COOPERATION, cluster(group_code_master)
							outreg2 using "table2.xls", excel dec(2) keep(treatment_alt) aster(se) br nocons append
						
						restore
					
					* 2 treatment dummies
					
						preserve
						
						qui avg_effect $I_COOPERATION if mandingo==0, ///
							effectvar(treatment_1 treatment_2) controltest(control==1) x(treatment_1 treatment_2 $I_CONTROLS $FE) cluster(group_code_master)
								outreg2 treatment_1 treatment_2 using "table2.xls", excel dec(2) aster(se) br append
						foreach x in $I_COOPERATION {
							qui drop if `x'==.
							}		
						foreach x in $I_COOPERATION {
							qui reg `x' treatment_1 treatment_2 $I_CONTROLS $FE if mandingo==0
								estimates store `x'
								}
							qui suest $I_COOPERATION, cluster(group_code_master)
							outreg2 using "table2.xls", excel dec(2) keep(treatment_1 treatment_2) aster(se) br nocons append
						
						restore

						

	* Replicate table 3																				
					
					* 1 treatment dummy
						
						preserve
						
						qui avg_effect $G_DISCRIMINATION_alt if ind_code==1, ///
							effectvar(treatment_alt) controltest(treatment_alt==0) x(treatment_alt $G_CONTROLS $FE)
								outreg2 treatment_alt using "table3.xls", excel dec(2) aster(se) br replace
						foreach x in $G_DISCRIMINATION_alt {
							qui drop if `x'==.
							}		
						foreach x in $G_DISCRIMINATION_alt {
							qui reg `x' treatment_alt $G_CONTROLS $FE if ind_code==1
								estimates store `x'
								}
							qui suest $G_DISCRIMINATION_alt
							outreg2 using "table3.xls", excel dec(2) keep(treatment_alt) aster(se) br nocons append
						
						restore
					
					* 2 treatment dummies
					
						preserve
						
						qui avg_effect $G_DISCRIMINATION_alt if ind_code==1, ///
							effectvar(treatment_1 treatment_2) controltest(control==1) x(treatment_1 treatment_2 $G_CONTROLS $FE)
								outreg2 treatment_1 treatment_2 using "table3.xls", excel dec(2) aster(se) br append
						foreach x in $G_DISCRIMINATION_alt {
							qui drop if `x'==.
							}		
						foreach x in $G_DISCRIMINATION_alt {
							qui reg `x' treatment_1 treatment_2 $G_CONTROLS $FE if ind_code==1
								estimates store `x'
								}
							qui suest $G_DISCRIMINATION_alt
							outreg2 using "table3.xls", excel dec(2) keep(treatment_1 treatment_2) aster(se) br nocons append
						
						restore

						



	* Replicate table 4
																												
					* 1 treatment dummy
						
						preserve
						
						qui avg_effect $I_DISCRIMINATION_alt if mandingo==0, ///
							effectvar(treatment_alt) controltest(treatment_alt==0) x(treatment_alt $I_CONTROLS $FE) cluster(group_code_master)
								outreg2 treatment_alt using "table4.xls", excel dec(2) aster(se) br replace
						foreach x in $I_DISCRIMINATION_alt {
							qui drop if `x'==.
							}		
						foreach x in $I_DISCRIMINATION_alt {
							qui reg `x' treatment_alt $I_CONTROLS $FE if mandingo==0
								estimates store `x'
								}
							qui suest $I_DISCRIMINATION_alt, cluster(group_code_master)
							outreg2 using "table4.xls", excel dec(2) keep(treatment_alt) aster(se) br nocons append
						
						restore
					
					* 2 treatment dummies
					
						preserve
						
						qui avg_effect $I_DISCRIMINATION_alt if mandingo==0, ///
							effectvar(treatment_1 treatment_2) controltest(control==1) x(treatment_1 treatment_2 $I_CONTROLS $FE) cluster(group_code_master)
								outreg2 treatment_1 treatment_2 using "table4.xls", excel dec(2) aster(se) br append
						foreach x in $I_DISCRIMINATION_alt {
							qui drop if `x'==.
							}		
						foreach x in $I_DISCRIMINATION_alt {
							qui reg `x' treatment_1 treatment_2 $I_CONTROLS $FE if mandingo==0
								estimates store `x'
								}
							qui suest $I_DISCRIMINATION_alt, cluster(group_code_master)
							outreg2 using "table4.xls", excel dec(2) keep(treatment_1 treatment_2) aster(se) br nocons append
						
						restore
			
			
			
							
	* Replicate table 5
																								
					preserve
					
					qui avg_effect $G_COOPERATION_hetero if ind_code==1, ///
						effectvar(hetero3 hetero4) controltest(hetero1_2==1) x(hetero3 hetero4 $G_CONTROLS $FE)
							outreg2 hetero3 hetero4 using "table5.xls", excel dec(2) aster(se) br replace
					foreach x in $G_COOPERATION_hetero {
						qui drop if `x'==.
						}		
					foreach x in $G_COOPERATION_hetero {
						qui reg `x' hetero3 hetero4 $G_CONTROLS $FE if ind_code==1
							estimates store `x'
							}
						qui suest $G_COOPERATION_hetero
						outreg2 using "table5.xls", excel dec(2) keep(hetero3 hetero4) aster(se) br nocons append
						
					restore
					

			
	
	* Replicate table 6
													
				foreach y in I_COOPERATION_hetero {
					preserve
					
					qui avg_effect $I_COOPERATION_hetero if mandingo==0, ///
						effectvar(hetero3 hetero4) controltest(hetero1_2==1) x(hetero3 hetero4 $I_CONTROLS $FE) cluster(group_code_master)
							outreg2 hetero3 hetero4 using "table6.xls", excel dec(2) aster(se) br replace
					foreach x in $I_COOPERATION_hetero {
						qui drop if `x'==.
						}		
					foreach x in $I_COOPERATION_hetero {
						qui reg `x' hetero3 hetero4 $I_CONTROLS $FE if mandingo==0
							estimates store `x'
							}
						qui suest $I_COOPERATION_hetero, cluster(group_code_master)
						outreg2 using "table6.xls", excel dec(2) keep(hetero3 hetero4) aster(se) br nocons append
					
					restore
					}

	
							
							
	* Replicate table 7
																		
					preserve
					
					qui avg_effect $G_DISCRIMINATION_hetero if ind_code==1, ///
						effectvar(hetero3 hetero4) controltest(hetero1_2==1) x(hetero3 hetero4 $G_CONTROLS $FE)
							outreg2 hetero3 hetero4 using "table7.xls", excel dec(2) aster(se) br replace
					foreach x in $G_DISCRIMINATION_hetero {
						qui drop if `x'==.
						}		
					foreach x in $G_DISCRIMINATION_hetero {
						qui reg `x' hetero3 hetero4 $G_CONTROLS $FE if ind_code==1
							estimates store `x'
							}
						qui suest $G_DISCRIMINATION_hetero
						outreg2 using "table7.xls", excel dec(2) keep(hetero3 hetero4) aster(se) br nocons append
					
					restore

						

						
									
	
	* Replicate table 8
							
					preserve
					
					qui avg_effect $I_DISCRIMINATION_hetero if mandingo==0, ///
						effectvar(hetero3 hetero4) controltest(hetero1_2==1) x(hetero3 hetero4 $I_CONTROLS $FE) cluster(group_code_master)
							outreg2 hetero3 hetero4 using "table8.xls", excel dec(2) aster(se) br replace
					foreach x in $I_DISCRIMINATION_hetero {
						qui drop if `x'==.
						}		
					foreach x in $I_DISCRIMINATION_hetero {
						qui reg `x' hetero3 hetero4 $I_CONTROLS $FE if mandingo==0
							estimates store `x'
							}
						qui suest $I_DISCRIMINATION_hetero, cluster(group_code_master)
						outreg2 using "table8.xls", excel dec(2) keep(hetero3 hetero4) aster(se) br nocons append
					
					restore
	
	

						
						

************
* APPENDIX *
************	


	* Replicate table A1

					cap matrix drop A
					cap matrix drop B
					cap matrix drop C
	
					foreach x of varlist $I_CONTROLS {
						summ `x'
							scalar `x'mean = r(mean)
							scalar `x'sd = -r(sd)
						}
	
					foreach x of varlist $I_CONTROLS {																
						matrix i`x'=(`x'mean \ `x'sd )
						}
	
					foreach x of varlist $I_CONTROLS {																
						matrix A = nullmat(A) \ i`x'
						}

					foreach x of varlist $G_CONTROLS {
						summ `x' if ind_code==1
							scalar `x'mean = r(mean)
							scalar `x'sd = -r(sd)
						}
	
					foreach x of varlist $G_CONTROLS {																
						matrix g`x'=(`x'mean \ `x'sd )
						}
	
					foreach x of varlist $G_CONTROLS {																
						matrix B = nullmat(B) \ g`x'
						}

						
					matrix C = (A, B)
					
					matrix list C
				
					local cnames `" "Ind" "Group" "' 
												
					xml_tab C, save("tableA1.xml") ///
						sheet(`g',color(1)) replace noisily cnames(`cnames') font("Times New Roman" 12) format((SCLR0) (SCCR0 NBCR2))						
	

	
	
	* Replicate table A2, columns 1-3

				cap matrix drop A
				cap matrix drop B
				cap matrix drop C
				cap matrix drop D

				foreach x of varlist $I_DISCRIMINATION {
					summ `x'
						scalar `x'mean = r(mean)
						scalar `x'sd = -r(sd)

					summ `x' if mandingo==1
						scalar m`x'mean = r(mean)
						scalar m`x'sd = -r(sd)

					summ `x' if mandingo==0
						scalar nm`x'mean = r(mean)
						scalar nm`x'sd = -r(sd)

					}

				foreach x of varlist $I_DISCRIMINATION {																
					matrix i`x'=(`x'mean \ `x'sd )
					matrix im`x'=(m`x'mean \ m`x'sd )
					matrix inm`x'=(nm`x'mean \ nm`x'sd )
					}

				foreach x of varlist $I_DISCRIMINATION {																
					matrix A = nullmat(A) \ i`x'
					matrix B = nullmat(B) \ im`x'
					matrix C = nullmat(C) \ inm`x'
					}
				
				matrix D = (A, B, C)
				
				matrix list D
			
				local cnames `" "Ind_All" "Ind_Mand" "Ind_Non_Mand"  "' 
											
				xml_tab D, save("tableA2_left.xml") ///
					sheet(`g',color(1)) replace noisily cnames(`cnames') font("Times New Roman" 12) format((SCLR0) (SCCR0 NBCR2))


	

	* Replicate table A2, column 4

				cap matrix drop A

				foreach x of varlist $G_DISCRIMINATION {
					summ `x' if ind_code==1
						scalar `x'mean = r(mean)
						scalar `x'sd = -r(sd)
					}

				foreach x of varlist $G_DISCRIMINATION {																
					matrix g`x'= (`x'mean \ `x'sd )
					}

				foreach x of varlist $G_DISCRIMINATION {																
					matrix A = nullmat(A) \ g`x'
					}
								
				matrix list A
			
				local cnames `" "Group" "' 
											
				xml_tab A, save("tableA2_right.xml") ///
					sheet(`g',color(1)) replace noisily cnames(`cnames') font("Times New Roman" 12) format((SCLR0) (SCCR0 NBCR2))


	
	
	* Replicate table A3, columns 1-3

				cap matrix drop A
				cap matrix drop B
				cap matrix drop C
				cap matrix drop D

				foreach x of varlist $I_COOPERATION {
					summ `x'
						scalar `x'mean = r(mean)
						scalar `x'sd = -r(sd)

					summ `x' if mandingo==1
						scalar m`x'mean = r(mean)
						scalar m`x'sd = -r(sd)

					summ `x' if mandingo==0
						scalar nm`x'mean = r(mean)
						scalar nm`x'sd = -r(sd)

					}

				foreach x of varlist $I_COOPERATION {																
					matrix i`x'=(`x'mean \ `x'sd )
					matrix im`x'=(m`x'mean \ m`x'sd )
					matrix inm`x'=(nm`x'mean \ nm`x'sd )
					}

				foreach x of varlist $I_COOPERATION {																
					matrix A = nullmat(A) \ i`x'
					matrix B = nullmat(B) \ im`x'
					matrix C = nullmat(C) \ inm`x'
					}
				
				matrix D = (A, B, C)
				
				matrix list D
			
				local cnames `" "Ind_All" "Ind_Mand" "Ind_Non_Mand"  "' 
											
				xml_tab D, save("tableA3_left.xml") ///
					sheet(`g',color(1)) replace noisily cnames(`cnames') font("Times New Roman" 12) format((SCLR0) (SCCR0 NBCR2))

	
	

	* Replicate table A3, column 4

				cap matrix drop A

				foreach x of varlist $G_COOPERATION {
					summ `x' if ind_code==1
						scalar `x'mean = r(mean)
						scalar `x'sd = -r(sd)
					}

				foreach x of varlist $G_COOPERATION {																
					matrix g`x'= (`x'mean \ `x'sd )
					}

				foreach x of varlist $G_COOPERATION {																
					matrix A = nullmat(A) \ g`x'
					}
								
				matrix list A
			
				local cnames `" "Group" "' 
											
				xml_tab A, save("tableA3_right.xml") ///
					sheet(`g',color(1)) replace noisily cnames(`cnames') font("Times New Roman" 12) format((SCLR0) (SCCR0 NBCR2))


	
	

					
	* Replicate table A4

					preserve
					
					keep if treatment_alt==1
					
					cap matrix drop A
					cap matrix drop B
					cap matrix drop C
	
					foreach x of varlist $I_DISCRIMINATION {

						summ `x' if mandingo==1 
							scalar m`x'mean = r(mean)
							scalar m`x'sd = -r(sd)

						summ `x' if mandingo==0 
							scalar nm`x'mean = r(mean)
							scalar nm`x'sd = -r(sd)

						ttest `x', by(mandingo) 
							}
	
					foreach x of varlist $I_DISCRIMINATION {																
						matrix mm`x'=(m`x'mean \ m`x'sd )
						matrix mnm`x'=(nm`x'mean \ nm`x'sd )
						}
	
					foreach x of varlist $I_DISCRIMINATION {																
						matrix A = nullmat(A) \ mm`x'
						matrix B = nullmat(B) \ mnm`x'
						}
					
					matrix C = (A, B)
					
					matrix list C
				
					local cnames `" "Mandingo" "Non-Mandingo" "' 
												
					xml_tab C, save("tableA4.xml") ///
						sheet(`g',color(1)) replace noisily cnames(`cnames') font("Times New Roman" 12) format((SCLR0) (SCCR0 NBCR2))

					restore
					
					
					
	
	* Replicate table A5

					preserve
					
					keep if treatment_alt==1
					
					cap matrix drop A
					cap matrix drop B
					cap matrix drop C
	
					foreach x of varlist $I_COOPERATION {

						summ `x' if mandingo==1 
							scalar m`x'mean = r(mean)
							scalar m`x'sd = -r(sd)

						summ `x' if mandingo==0 
							scalar nm`x'mean = r(mean)
							scalar nm`x'sd = -r(sd)

						ttest `x', by(mandingo) 
							}
	
					foreach x of varlist $I_COOPERATION {																
						matrix mm`x'=(m`x'mean \ m`x'sd )
						matrix mnm`x'=(nm`x'mean \ nm`x'sd )
						}
	
					foreach x of varlist $I_COOPERATION {																
						matrix A = nullmat(A) \ mm`x'
						matrix B = nullmat(B) \ mnm`x'
						}
					
					matrix C = (A, B)
					
					matrix list C
				
					local cnames `" "Mandingo" "Non-Mandingo" "' 
												
					xml_tab C, save("tableA5.xml") ///
						sheet(`g',color(1)) replace noisily cnames(`cnames') font("Times New Roman" 12) format((SCLR0) (SCCR0 NBCR2))

					restore
					
						
							

	* Replicate table A6, columns 1-2

				mlogit treatment $I_CONTROLS $FE if mandingo==0, cluster(group_code_master)
					test $I_CONTROLS
					local chi2 = r(chi2)
					local p = r(p)
					outreg2 using "tableA6_left.xls", excel aster(se) dec(2) br nocons replace addtext(chi2, `chi2', p, `p') keep($I_CONTROLS)

					
					
					
	* Replicate table A6, columns 3-4
						
				mlogit treatment $G_CONTROLS $FE if ind_code==1
					test $G_CONTROLS
					local chi2 = r(chi2)
					local p = r(p)
					outreg2 using "tableA6_right.xls", excel aster(se) dec(2) br nocons replace addtext(chi2, `chi2', p, `p') keep($G_CONTROLS)
	

	
	
	* Replicate table A7
																																																							
					* 1 treatment dummy
						
						preserve
						
						qui avg_effect $G_DISCRIMINATION if ind_code==1, ///
							effectvar(treatment_alt) controltest(treatment_alt==0) x(treatment_alt $G_CONTROLS $FE)
								outreg2 treatment_alt using "tableA7.xls", excel dec(2) aster(se) br replace
						foreach x in $G_DISCRIMINATION {
							qui drop if `x'==.
							}		
						foreach x in $G_DISCRIMINATION {
							qui reg `x' treatment_alt $G_CONTROLS $FE if ind_code==1
								estimates store `x'
								}
							qui suest $G_DISCRIMINATION
							outreg2 using "tableA7.xls", excel dec(2) keep(treatment_alt) aster(se) br nocons append
						
						restore
					
					* 2 treatment dummies
					
						preserve
						
						qui avg_effect $G_DISCRIMINATION if ind_code==1, ///
							effectvar(treatment_1 treatment_2) controltest(control==1) x(treatment_1 treatment_2 $G_CONTROLS $FE)
								outreg2 treatment_1 treatment_2 using "tableA7.xls", excel dec(2) aster(se) br append
						foreach x in $G_DISCRIMINATION {
							qui drop if `x'==.
							}		
						foreach x in $G_DISCRIMINATION {
							qui reg `x' treatment_1 treatment_2 $G_CONTROLS $FE if ind_code==1
								estimates store `x'
								}
							qui suest $G_DISCRIMINATION
							outreg2 using "tableA7.xls", excel dec(2) keep(treatment_1 treatment_2) aster(se) br nocons append
						
						restore

						

						
						
	* Replicate table A8
																												
					* 1 treatment dummy
						
						preserve
						
						qui avg_effect $I_DISCRIMINATION if mandingo==0, ///
							effectvar(treatment_alt) controltest(treatment_alt==0) x(treatment_alt $I_CONTROLS $FE) cluster(group_code_master)
								outreg2 treatment_alt using "tableA8.xls", excel dec(2) aster(se) br replace
						foreach x in $I_DISCRIMINATION {
							qui drop if `x'==.
							}		
						foreach x in $I_DISCRIMINATION {
							qui reg `x' treatment_alt $I_CONTROLS $FE if mandingo==0
								estimates store `x'
								}
							qui suest $I_DISCRIMINATION, cluster(group_code_master)
							outreg2 using "tableA8.xls", excel dec(2) keep(treatment_alt) aster(se) br nocons append
						
						restore
					
					* 2 treatment dummies
					
						preserve
						
						qui avg_effect $I_DISCRIMINATION if mandingo==0, ///
							effectvar(treatment_1 treatment_2) controltest(control==1) x(treatment_1 treatment_2 $I_CONTROLS $FE) cluster(group_code_master)
								outreg2 treatment_1 treatment_2 using "tableA8.xls", excel dec(2) aster(se) br append
						foreach x in $I_DISCRIMINATION {
							qui drop if `x'==.
							}		
						foreach x in $I_DISCRIMINATION {
							qui reg `x' treatment_1 treatment_2 $I_CONTROLS $FE if mandingo==0
								estimates store `x'
								}
							qui suest $I_DISCRIMINATION, cluster(group_code_master)
							outreg2 using "tableA8.xls", excel dec(2) keep(treatment_1 treatment_2) aster(se) br nocons append
						
						restore

						
								
	* Replicate table A9
																																				
					* 1 treatment dummy
						
						preserve
						
						qui avg_effect $G_COOPERATION_alt if ind_code==1, ///
							effectvar(treatment_alt) controltest(treatment_alt==0) x(treatment_alt $G_CONTROLS $FE)
								outreg2 treatment_alt using "tableA9.xls", excel dec(2) aster(se) br replace
						foreach x in $G_COOPERATION_alt {
							qui drop if `x'==.
							}		
						foreach x in $G_COOPERATION_alt {
							qui reg `x' treatment_alt $G_CONTROLS $FE if ind_code==1
								estimates store `x'
								}
							qui suest $G_COOPERATION_alt
							outreg2 using "tableA9.xls", excel dec(2) keep(treatment_alt) aster(se) br nocons append
						
						restore
					
					* 2 treatment dummies
					
						preserve
						
						qui avg_effect $G_COOPERATION_alt if ind_code==1, ///
							effectvar(treatment_1 treatment_2) controltest(control==1) x(treatment_1 treatment_2 $G_CONTROLS $FE)
								outreg2 treatment_1 treatment_2 using "tableA9.xls", excel dec(2) aster(se) br append
						foreach x in $G_COOPERATION_alt {
							qui drop if `x'==.
							}		
						foreach x in $G_COOPERATION_alt {
							qui reg `x' treatment_1 treatment_2 $G_CONTROLS $FE if ind_code==1
								estimates store `x'
								}
							qui suest $G_COOPERATION_alt
							outreg2 using "tableA9.xls", excel dec(2) keep(treatment_1 treatment_2) aster(se) br nocons append
						
						restore

						
						
		
	
	* Replicate table A10 
				
				foreach y in g_cooperation_index g_discrimination_index_alt {

					reg `y'_std treatment_alt $G_CONTROLS $FE if ind_code==1
						outreg2 using "tableA10.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_alt) append
		
					reg `y'_pcf treatment_alt $G_CONTROLS $FE if ind_code==1
						outreg2 using "tableA10.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_alt) append

					reg `y'_std treatment_1 treatment_2 $G_CONTROLS $FE if ind_code==1
						outreg2 using "tableA10.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_1 treatment_2) append
		
					reg `y'_pcf treatment_1 treatment_2 $G_CONTROLS $FE if ind_code==1
						outreg2 using "tableA10.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_1 treatment_2) append

					}

					

	* Replicate table A11
					
				foreach x in i_cooperation_index i_discrimination_index_alt {

					reg `x'_std treatment_alt $I_CONTROLS $FE if mandingo==0, cluster(group_code_master)
						outreg2 using "tableA11.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_alt) append

					reg `x'_pcf treatment_alt $I_CONTROLS $FE if mandingo==0, cluster(group_code_master)
						outreg2 using "tableA11.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_alt) append

					reg `x'_std treatment_1 treatment_2 $I_CONTROLS $FE if mandingo==0, cluster(group_code_master)
						outreg2 using "tableA11.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_1 treatment_2) append

					reg `x'_pcf treatment_1 treatment_2 $I_CONTROLS $FE if mandingo==0, cluster(group_code_master)
						outreg2 using "tableA11.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_1 treatment_2) append

					}
								

					
					
	* Replicate table A12 
				
				foreach y in g_cooperation_index g_discrimination_index_alt {

					reg `y'_std treatment_alt $G_CONTROLS $FE if ind_code==1, vce(bootstrap)
						outreg2 using "tableA12.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_alt) append
		
					reg `y'_pcf treatment_alt $G_CONTROLS $FE if ind_code==1, vce(bootstrap)
						outreg2 using "tableA12.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_alt) append

					reg `y'_std treatment_1 treatment_2 $G_CONTROLS $FE if ind_code==1, vce(bootstrap)
						outreg2 using "tableA12.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_1 treatment_2) append
		
					reg `y'_pcf treatment_1 treatment_2 $G_CONTROLS $FE if ind_code==1, vce(bootstrap)
						outreg2 using "tableA12.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_1 treatment_2) append

					}

					

	* Replicate table A13
					
				foreach x in i_cooperation_index i_discrimination_index_alt {

					reg `x'_std treatment_alt $I_CONTROLS $FE if mandingo==0, cluster(group_code_master) vce(bootstrap)
						outreg2 using "tableA13.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_alt) append

					reg `x'_pcf treatment_alt $I_CONTROLS $FE if mandingo==0, cluster(group_code_master) vce(bootstrap)
						outreg2 using "tableA13.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_alt) append

					reg `x'_std treatment_1 treatment_2 $I_CONTROLS $FE if mandingo==0, cluster(group_code_master) vce(bootstrap)
						outreg2 using "tableA13.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_1 treatment_2) append

					reg `x'_pcf treatment_1 treatment_2 $I_CONTROLS $FE if mandingo==0, cluster(group_code_master) vce(bootstrap)
						outreg2 using "tableA13.xls", ///
							excel aster(se) dec(2) br nocons addtext(FE, Y) keep(treatment_1 treatment_2) append

					}
								

							

	
	* Replicate table A14
				
				foreach z in lorma kpelle bassa grebo mano gio {
					
					preserve
				
					ren `z'_mandingo_alt `z'_alt
				
					foreach y in G_COOPERATION {
						qui avg_effect $`y' if ind_code==1, ///
							effectvar(`z'_alt) controltest(`z'_alt==0) x(`z'_alt $G_CONTROLS $FE)
								outreg2 `z'_alt using "tableA14.xls", excel dec(2) aster(se) br append
						
					foreach x in $`y' {
						qui drop if `x'==.
						}		
							
					foreach x in $`y' {
						qui reg `x' `z'_alt $G_CONTROLS $FE if ind_code==1
							estimates store `x'
							}
						qui suest $`y'
						outreg2 using "tableA14.xls", excel dec(2) keep(`z'_alt) aster(se) br nocons append
						}
					
					restore	
					}
						


						
	* Replicate table A15
				
				foreach z in lorma kpelle bassa grebo mano gio {
					
					preserve
				
					ren `z'_mandingo_alt `z'_alt
				
					foreach y in G_DISCRIMINATION_alt {
						qui avg_effect $`y' if ind_code==1, ///
							effectvar(`z'_alt) controltest(`z'_alt==0) x(`z'_alt $G_CONTROLS $FE)
								outreg2 `z'_alt using "tableA15.xls", excel dec(2) aster(se) br append
						
					foreach x in $`y' {
						qui drop if `x'==.
						}		
							
					foreach x in $`y' {
						qui reg `x' `z'_alt $G_CONTROLS $FE if ind_code==1
							estimates store `x'
							}
						qui suest $`y'
						outreg2 using "tableA15.xls", excel dec(2) keep(`z'_alt) aster(se) br nocons append
						}
					
					restore	
					}
						

						
